aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors
diff options
context:
space:
mode:
authorVadim Yanitskiy <vyanitskiy@sysmocom.de>2022-10-19 15:36:09 +0700
committerAndersBroman <a.broman58@gmail.com>2022-10-31 12:12:24 +0000
commit9de9a7900f25c9378fd8c11b60831a60c0776196 (patch)
treeca0b3ca1095f03c9c8667018dca4ef142bf0a7b4 /epan/dissectors
parent3829e598a5c43b7afb143f6e737abe0d3c92a2f8 (diff)
GSM A RR: de_rr_meas_res(): also show padding as a tree item
Diffstat (limited to 'epan/dissectors')
-rw-r--r--epan/dissectors/packet-gsm_a_rr.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/epan/dissectors/packet-gsm_a_rr.c b/epan/dissectors/packet-gsm_a_rr.c
index 5ed484f5b1..7859ae4fc6 100644
--- a/epan/dissectors/packet-gsm_a_rr.c
+++ b/epan/dissectors/packet-gsm_a_rr.c
@@ -4343,9 +4343,10 @@ de_rr_meas_res(tvbuff_t *tvb, proto_tree *subtree, packet_info *pinfo _U_, guint
no_ncell_m -= 1;
}
-
/* The Measurement Results is a type 3 information element with 17 octets length.
- * Thus the value part is 17 - 1 == 16 octets long. */
+ * Thus the value part is 17 - 1 == 16 octets long. Unused bits are set to zero. */
+ gsm_rr_padding_bits(subtree, tvb, bit_offset, 16, 0x00);
+
return(16);
}